==> web_frontend_binect-0.0.27.gem: app/controllers/web_frontend_binect/documents_controller.rb <==
require_dependency "web_frontend_binect/authenticated_controller"
require 'refile/rails/attachment_helper.rb'
require 'securerandom'

module WebFrontendBinect
    class DocumentsController < ApplicationController
        before_action :set_document, only: [:show, :edit, :update, :destroy, :validate]
        before_action :check_authentication, only: :show

        # GET /documents
        def index
            if current_user.present?
                @documents = Nukleus::Document.all_by_user_id(current_user.id)
            else
                @documents = Nukleus::Document.all_by_session_id(session[:session_id])
            end
        end

        # GET /documents/1
        def show
        end

        # GET /documents/new
        def new
            @document = Nukleus::Document.new
        end

        # GET /documents/1/edit
        def edit
        end

        # POST /documents
        def create
            filtered_params = document_params

            filtered_params[:document_id] = SecureRandom.uuid

            if current_user.present?
                filtered_params[:user_id] = current_user.id
            else
                filtered_params[:session_id] = session[:session_id]
            end
            @document = Nukleus::Document.new(filtered_params)

            if @document.save
                #redirect_to @document, notice: 'Document was successfully created.'
                flash[:notice] = "Der Brief wurde erfolgreich erstellt."
                render :new
            else
                flash[:error] = "Der Brief wurde erfolgreich erstellt."
                render :new
            end
        end

        # PATCH/PUT /documents/1
        def update
            if @document.update(document_params)
                redirect_to @document, notice: 'Der Brief wurde erfolgreich aktualisiert'
            else
                render :edit
            end
        end

        # DELETE /documents/1
        def destroy
            @document.destroy
            redirect_to documents_url, notice: 'Der Brief wurde erfolgreich gelöscht.'
        end

        # GET /documents/1/validate
        def validate
            @result = @document.validate
            render :validate, :layout => false
        end

        private
        # Use callbacks to share common setup or constraints between actions.
        def set_document
            @document = Nukleus::Document.find(params[:id])
        end

        # Only allow a trusted parameter "white list" through.
        def document_params
            params.require(:document).permit(:document_file, :document_id, :zoom_level, :x_offset, :y_offset, :is_color, :is_simplex, :is_international, :price, :is_international)
        end

        def check_authentication
            # Make sure that old stored URL's from browser history will not work.
            if current_user.present?
                fail WebFrontendBinect::ApplicationController::NotAuthorised if current_user.id != @document.user_id
            else
                fail WebFrontendBinect::ApplicationController::NotAuthorised if session[:session_id] !=  @document.session_id
            end
        end
    end
end

==> web_frontend_binect-0.0.45.gem: app/controllers/web_frontend_binect/documents_controller.rb <==
require_dependency "web_frontend_binect/authenticated_controller"
require 'refile/rails/attachment_helper.rb'
require 'securerandom'

module WebFrontendBinect
    class DocumentsController < ApplicationController
        before_action :set_document, only: [:show, :edit, :update, :destroy, :validate]
        before_action :check_authentication, only: :show

        # GET /documents
        def index
            if current_user.present?
                @documents = Nukleus::Document.all_by_user_id(current_user.id)
            else
                @documents = Nukleus::Document.all_by_session_id(session[:session_id])
            end
        end

        # GET /documents/1
        def show
        end

        # GET /documents/new
        def new
            @document = Nukleus::Document.new
        end

        # GET /documents/1/edit
        def edit
        end

        # POST /documents
        def create
            filtered_params = document_params

            filtered_params[:document_id] = SecureRandom.uuid

            if current_user.present?
                filtered_params[:user_id] = current_user.id
            else
                filtered_params[:session_id] = session[:session_id]
            end
            @document = Nukleus::Document.new(filtered_params)

            if @document.save
                #redirect_to @document, notice: 'Document was successfully created.'
                flash[:notice] = "Der Brief wurde erfolgreich erstellt."
                render :new
            else
                flash[:error] = "Der Brief wurde erfolgreich erstellt."
                render :new
            end
        end

        # PATCH/PUT /documents/1
        def update
            if @document.update(document_params)
                redirect_to documents_url, notice: 'Der Brief wurde erfolgreich aktualisiert'
            else
                render :edit
            end
        end

        # DELETE /documents/1
        def destroy
            @document.destroy
            redirect_to documents_url, notice: 'Der Brief wurde erfolgreich gelöscht.'
        end

        # GET /documents/1/validate
        def validate
            @result = @document.validate
            render :validate, :layout => false
        end

        private
        # Use callbacks to share common setup or constraints between actions.
        def set_document
            @document = Nukleus::Document.find(params[:id])
        end

        # Only allow a trusted parameter "white list" through.
        def document_params
            params.require(:document).permit(:document_file, :document_id, :zoom_level, :x_offset, :y_offset, :is_color, :is_simplex, :is_international, :price, :is_international)
        end

        def check_authentication
            # Make sure that old stored URL's from browser history will not work.
            if current_user.present?
                fail WebFrontendBinect::ApplicationController::NotAuthorised if current_user.id != @document.user_id
            else
                fail WebFrontendBinect::ApplicationController::NotAuthorised if session[:session_id] !=  @document.session_id
            end
        end
    end
end
